@@ -1,10 +1,10 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
 class HelloWorld: public QpThread {
     public:
 	~HelloWorld() {Join();}
-	void Main() {
+	virtual void Main() {
 		cout << "Hello World" << endl;
 	}
 };
