@@ -1,4 +1,4 @@
-#include <iostream.h>
+#include "ex.h"
 #include <stdlib.h>
 #include <qpthr/qp.h>
 #include <qpthr/qp_work.h>
