@@ -1,3 +1,7 @@
+#ifdef WIN32
+#error "This example is not supported on Windows!"
+#endif // WIN32
+
 #include <sys/resource.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -81,6 +85,11 @@ class TimeMeasure {
 };
 
 
+/*
+ * 
+ * Test 1
+ * 
+ */
 void test1(const char *label, QpLockBase *lock, int iter)
 {
 	TimeMeasure tme;
@@ -97,6 +106,38 @@ void test1(const char *label, QpLockBase *lock, int iter)
 	tme.Print();
 }
 
+void test1_rw_read(const char *label, QpRWLockBase *lock, int iter)
+{
+	TimeMeasure tme;
+	int i;
+	
+	cout << "test 1 " << label << " ";
+	cout.flush();
+	tme.Start();
+	for (i = 0; i < iter; i++) {
+		lock->ReadLock();
+		lock->Unlock();
+	}
+	tme.Stop();
+	tme.Print();
+}
+
+void test1_rw_write(const char *label, QpRWLockBase *lock, int iter)
+{
+	TimeMeasure tme;
+	int i;
+	
+	cout << "test 1 " << label << " ";
+	cout.flush();
+	tme.Start();
+	for (i = 0; i < iter; i++) {
+		lock->WriteLock();
+		lock->Unlock();
+	}
+	tme.Stop();
+	tme.Print();
+}
+
 void test1_pthread_mutex(const char *label, int iter)
 {
 	TimeMeasure tme;
@@ -135,6 +176,11 @@ void test1_tas_mutex(const char *label, int iter)
 	tme.Print();
 }
 
+/*
+ * 
+ * Test 2
+ * 
+ */
 class Test2Thread: public QpThread {
     private:
 	QpLockBase *t_lock;
@@ -173,6 +219,11 @@ void test2(const char *label, QpLockBase *lock, int iter, int thr)
 }
 
 
+/*
+ * 
+ * Test 3
+ * 
+ */
 class Test3Thread: public QpThread {
     private:
 	QpLockBase *t_lock;
@@ -261,6 +312,8 @@ int main(int argc, char *argv[])
 	QpMutexEx	mutex_ex;
 	QpSem		sem;
 	QpAsyncSafeSem	async_sem;
+	QpRWLock	rw_lock;
+	QpRWLockEx	rw_lock_ex;
 	
 	while ((c = getopt(argc, argv, "i:t:y")) != EOF) {
 		switch (c) {
@@ -286,7 +339,10 @@ int main(int argc, char *argv[])
 	test1("QpMutexEx      ", &mutex_ex, iter);
 	test1("QpSem          ", &sem, iter);
 	test1("QpAsyncSafeSem ", &async_sem, iter);
-	
+	test1_rw_read("QpRWLock Read  ", &rw_lock, iter);
+	test1_rw_write("QpRWLock Write ", &rw_lock, iter);
+	test1_rw_read("QpRWLockEx Read", &rw_lock_ex, iter);
+	test1_rw_write("QpRWLockEx Write", &rw_lock_ex, iter);
 	cout << endl;
 	
 	test2("QpSpinLock     ", &spin_lock, iter, thr);
