@@ -1,4 +1,4 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
 
@@ -15,10 +15,10 @@ QpTSDT<PerThreadObject> tsd;
 
 class TsdtThread: public QpThread {
     public:
-	~TsdtThread() {Join();}
-	void Main() {
+	virtual ~TsdtThread() {Join();}
+	virtual void Main() {
 		tsd->Invoke();
-		sleep(1);
+		QpThread::Sleep(1);
 	}
 };
 
